@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2022 EPFL/Blue Brain Project
+# Copyright (c) 2015-2023 EPFL/Blue Brain Project
 # All rights reserved. Do not distribute without permission.
 #
 # Responsible Author: adrien.fleury@epfl.ch
@@ -30,12 +30,11 @@ To make a movie, frames must be rendered separately. This subpackage includes
 helpers to select the frames to render based on movie specifications.
 """
 
-from .movie import Movie
-from .movie_error import MovieError
+from .movie import Movie, MovieError
 from .movie_frames import MovieFrames
 
 __all__ = [
-    'Movie',
-    'MovieError',
-    'MovieFrames',
+    "Movie",
+    "MovieError",
+    "MovieFrames",
 ]
