@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2022 EPFL/Blue Brain Project
+# Copyright (c) 2015-2023 EPFL/Blue Brain Project
 # All rights reserved. Do not distribute without permission.
 #
 # Responsible Author: adrien.fleury@epfl.ch
@@ -20,11 +20,12 @@
 
 from typing import Protocol
 
-from .messages import JsonRpcError, JsonRpcProgress, JsonRpcReply
+from .json_rpc_error import JsonRpcError
+from .json_rpc_progress import JsonRpcProgress
+from .json_rpc_reply import JsonRpcReply
 
 
 class JsonRpcListener(Protocol):
-
     def on_reply(self, reply: JsonRpcReply) -> None:
         pass
 
