@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2022 EPFL/Blue Brain Project
+# Copyright (c) 2015-2023 EPFL/Blue Brain Project
 # All rights reserved. Do not distribute without permission.
 #
 # Responsible Author: adrien.fleury@epfl.ch
@@ -18,22 +18,27 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from .exceptions import *
-from .ssl_client_context import SslClientContext
+from .errors import (
+    ConnectionClosedError,
+    InvalidServerCertificateError,
+    ProtocolError,
+    ServiceUnavailableError,
+    WebSocketError,
+)
 from .web_socket import WebSocket
 from .web_socket_client import WebSocketClient
-from .web_socket_connector import WebSocketConnector
+from .web_socket_connector import SslClientContext, WebSocketConnector
 from .web_socket_listener import WebSocketListener
 
 __all__ = [
-    'ConnectionClosedError',
-    'InvalidServerCertificateError',
-    'ProtocolError',
-    'ServiceUnavailableError',
-    'SslClientContext',
-    'WebSocket',
-    'WebSocketClient',
-    'WebSocketConnector',
-    'WebSocketError',
-    'WebSocketListener',
+    "ConnectionClosedError",
+    "InvalidServerCertificateError",
+    "ProtocolError",
+    "ServiceUnavailableError",
+    "SslClientContext",
+    "WebSocket",
+    "WebSocketClient",
+    "WebSocketConnector",
+    "WebSocketError",
+    "WebSocketListener",
 ]
