@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2022 EPFL/Blue Brain Project
+# Copyright (c) 2015-2023 EPFL/Blue Brain Project
 # All rights reserved. Do not distribute without permission.
 #
 # Responsible Author: adrien.fleury@epfl.ch
@@ -20,11 +20,10 @@
 
 from typing import Protocol, TypeVar
 
-T = TypeVar('T', bound='WebSocket')
+T = TypeVar("T", bound="WebSocket")
 
 
 class WebSocket(Protocol):
-
     def __enter__(self: T) -> T:
         return self
 
