@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2022 EPFL/Blue Brain Project
+# Copyright (c) 2015-2023 EPFL/Blue Brain Project
 # All rights reserved. Do not distribute without permission.
 #
 # Responsible Author: adrien.fleury@epfl.ch
@@ -24,20 +24,16 @@ Subpackage start braynsService as a subprocess from Python.
 Provides mainly helpers to generate the command line.
 """
 
-from .log_level import LogLevel
-from .manager import Manager
-from .plugin import Plugin
+from .manager import Manager, start
 from .process import Process
-from .service import Service
-from .ssl_server_context import SslServerContext
-from .start import start
+from .service import LogLevel, Plugin, Service, SslServerContext
 
 __all__ = [
-    'LogLevel',
-    'Manager',
-    'Plugin',
-    'Process',
-    'Service',
-    'SslServerContext',
-    'start',
+    "LogLevel",
+    "Manager",
+    "Plugin",
+    "Process",
+    "Service",
+    "SslServerContext",
+    "start",
 ]
